@@ -8,11 +8,11 @@ URL::List - Object-oriented methods of handling list of URLs.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 use Carp;
 use Domain::PublicSuffix;
@@ -60,13 +60,16 @@ use URI;
     #     ],
     # };
 
+    my $urls = $list->all; # All the URLs are still there, so use this...
+    $list->clear;          # ...to clear the list.
+
 =head1 DESCRIPTION
 
 URL:List is a module which helps you with distributing a list of URLs "evenly"
 based on the URLs' host name, domain name or TLD (top-level domain).
 
 This can be useful for crawlers, ie. giving out a list of URLs within specific
-domain names to different worker robots.
+hostnames, domain names and/or TLD names to different workers.
 
 =head1 METHODS
 
@@ -128,11 +131,38 @@ sub count {
     return scalar( @{$self->all} );
 }
 
+=head2 clear
+
+Clears the URL list.
+
+=cut
+
+sub clear {
+    my $self = shift;
+
+    $self->urls = [];
+}
+
+=head2 flush
+
+An alias for C<clear>.
+
+=cut
+
+sub flush {
+    return shift->clear;
+}
+
+#
+# DISTRIBUTIONS
+#
+
 =head2 distributions
 
-Returns a hash reference of all the possible distributions. This method should
-not be used directly, but is provided because it's a helper method for the
-methods mentioned below.
+Returns a hash reference of all the possible distributions.
+
+This method should not be used directly. Instead, the distributed_by_* methods
+should be used.
 
 =cut
 
@@ -170,15 +200,30 @@ sub _build_distributions {
 
         if ( $@ ) {
             carp "Failed to determine host from '" . $url . "'. Skipping it!";
+            next;
         }
 
         if ( defined $host && length $host ) {
             my $domain = $suffix->get_root_domain( $host );
             my $tld    = $suffix->tld;
 
-            push( @{$distributions{host}->{$host}},     $url );
-            push( @{$distributions{domain}->{$domain}}, $url ) if ( defined $domain && length $domain );
-            push( @{$distributions{tld}->{$tld}},       $url ) if ( defined $tld    && length $tld    );
+            push( @{$distributions{host}->{$host}}, $url );
+
+            if ( defined $domain && length $domain ) {
+                push( @{$distributions{domain}->{$domain}}, $url );
+            }
+            else {
+                carp "Failed to determine the domain name from '" . $url . "'. Skipping it!";
+                next;
+            }
+
+            if ( defined $tld && length $tld ) {
+                push( @{$distributions{tld}->{$tld}}, $url );
+            }
+            else {
+                carp "Failed to determine the TLD from '" . $url . "'. Skipping it!";
+                next;
+            }
         }
         else {
             carp "Failed to determine host from '" . $url . "'. Skipping it!";
